Table Configuration — SQLAlchemy 2.0 Documentation

Release: 2.0.17 | Release Date: June 23, 2023

# SQLAlchemy 2.0 Documentation

# Table Configuration

This section has moved; see Declarative Table Configuration.

## Using a Hybrid Approach with __table__

This section has moved; see Declarative with Imperative Table (a.k.a. Hybrid Declarative).

## Using Reflection with Declarative

This section has moved to Mapping Declaratively with Reflected Tables.